### Achilles: LLM-powered Python performance optimizer


## How to use Achilles

Install Achilles using the following command:

""" ACHILLES INSTALL COMMAND SHOULD BE PUT HERE """

Once Achilles is installed, you can optimize a python executable using the following command:

""" achilles optimize your_python_file.py --your_python_args """

If you've already ran Achilles once, you can benchmark it against the non-optimized python code with the following command:

""" achilles benchmark your_python_file.py --your_python_args """

To run a python executable using achillles, just type the following command:

""" achilles run your_python_file.py --your_python_args """
